summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteaccount.h')
-rw-r--r--kopete/libkopete/kopeteaccount.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kopete/libkopete/kopeteaccount.h b/kopete/libkopete/kopeteaccount.h
index 205b795f..b7915b5e 100644
--- a/kopete/libkopete/kopeteaccount.h
+++ b/kopete/libkopete/kopeteaccount.h
@@ -98,12 +98,12 @@ public:
};
/**
* @param tqparent the protocol for this account. The account is a child object of the
* protocol, so it will be automatically deleted when the protocol is.
* @param accountID the unique ID of this account.
* @param name the name of this TQObject.
*/
- Account(Protocol *tqparent, const TQString &accountID, const char *name=0L);
+ Account(Protocol *parent, const TQString &accountID, const char *name=0L);
~Account();
/**
@@ -277,16 +277,16 @@ public:
* @brief Create a new contact, adding it to an existing metacontact
*
* If a contact for this account with ID @p contactId is not already on the contact list,
* a new contact with that ID is created, and added to the metacontact @p tqparent.
*
* @param contactId the @ref Contact::contactId of the contact to create
* @param tqparent the tqparent metacontact (must not be 0)
* @param mode the mode used to add the contact. See addContact(const TQString&,const TQString&,Group*,AddMode) for details.
*
* @return @c true if creation of the contact succeeded or the contact was already in the list,
* @c false otherwise.
*/
- bool addContact( const TQString &contactId, MetaContact *tqparent, AddMode mode = DontChangeKABC );
+ bool addContact( const TQString &contactId, MetaContact *parent, AddMode mode = DontChangeKABC );
/**
* @brief Indicate whether the account is connected at all.
@@ -353,7 +353,7 @@ protected:
* contactId should be the accountID. The online status of the myself contact represents
* the account's status.
*
* The myself should have the @ref ContactList::myself() as tqparent metacontact
*
*/
void setMyself( Contact *myself );
@@ -364,7 +364,7 @@ protected:
* You shouldn't ever call this method yourself. To add contacts, use @ref addContact().
*
* This method is called by @ref addContact(). In this method, you should create the
- * new custom @ref Contact, using @p parentContact as the tqparent.
+ * new custom @ref Contact, using @p parentContact as the parent.
*
* If the metacontact is not temporary and the protocol supports it, you can add the
* contact to the server.
@@ -484,7 +484,7 @@ public slots:
/**
* Display the edit account widget for the account
*/
- void editAccount( TQWidget* tqparent = 0L );
+ void editAccount( TQWidget* parent = 0L );
/**
* Add a user to the blacklist. The default implementation calls
@@ -98,12 +98,12 @@ public:
};
/**
- * @param tqparent the protocol for this account. The account is a child object of the
+ * @param parent the protocol for this account. The account is a child object of the
* protocol, so it will be automatically deleted when the protocol is.
* @param accountID the unique ID of this account.
@@ -277,16 +277,16 @@ public:
*
* If a contact for this account with ID @p contactId is not already on the contact list,
- * a new contact with that ID is created, and added to the metacontact @p tqparent.
+ * a new contact with that ID is created, and added to the metacontact @p parent.
*
* @param contactId the @ref Contact::contactId of the contact to create
@@ -277,16 +277,16 @@ public:
*
* @param contactId the @ref Contact::contactId of the contact to create
- * @param tqparent the tqparent metacontact (must not be 0)
+ * @param parent the parent metacontact (must not be 0)
* @param mode the mode used to add the contact. See addContact(const TQString&,const TQString&,Group*,AddMode) for details.
*
@@ -353,7 +353,7 @@ protected:
* the account's status.
*
- * The myself should have the @ref ContactList::myself() as tqparent metacontact
+ * The myself should have the @ref ContactList::myself() as parent metacontact
*
*/